==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OsobaPracownik.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypPrzypisaniaPracownika;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OsobaPracownik extends GenericDPSObject {
    /**
     * OSOBA_PRACOWNIK.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * OSOBA_PRACOWNIK.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_PRZYPISAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikPrzypisalId;

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ZMIENIL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikZmienilId;

    /**
     * OSOBA_PRACOWNIK.DATA_PRZYPISANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataPrzypisania;

    /**
     * OSOBA_PRACOWNIK.DATA_ZMIANY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataZmiany;

    /**
     * OSOBA_PRACOWNIK.TYP_PRACOWNIKA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypPrzypisaniaPracownika typPracownika;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_PRACOWNIK.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * OSOBA_PRACOWNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return OSOBA_PRACOWNIK.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_PRACOWNIK.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OSOBA_PRACOWNIK.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return OSOBA_PRACOWNIK.PRACOWNIK_PRZYPISAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikPrzypisalId() {
        return pracownikPrzypisalId;
    }

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_PRZYPISAL_ID
     *
     * @param pracownikPrzypisalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikPrzypisalId(Long pracownikPrzypisalId) {
        this.pracownikPrzypisalId = pracownikPrzypisalId;
    }

    /**
     * @return OSOBA_PRACOWNIK.PRACOWNIK_ZMIENIL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikZmienilId() {
        return pracownikZmienilId;
    }

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ZMIENIL_ID
     *
     * @param pracownikZmienilId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikZmienilId(Long pracownikZmienilId) {
        this.pracownikZmienilId = pracownikZmienilId;
    }

    /**
     * @return OSOBA_PRACOWNIK.DATA_PRZYPISANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataPrzypisania() {
        return dataPrzypisania;
    }

    /**
     * OSOBA_PRACOWNIK.DATA_PRZYPISANIA
     *
     * @param dataPrzypisania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataPrzypisania(Date dataPrzypisania) {
        this.dataPrzypisania = dataPrzypisania;
    }

    /**
     * @return OSOBA_PRACOWNIK.DATA_ZMIANY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataZmiany() {
        return dataZmiany;
    }

    /**
     * OSOBA_PRACOWNIK.DATA_ZMIANY
     *
     * @param dataZmiany
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataZmiany(Date dataZmiany) {
        this.dataZmiany = dataZmiany;
    }

    /**
     * @return OSOBA_PRACOWNIK.TYP_PRACOWNIKA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypPrzypisaniaPracownika getTypPracownika() {
        return typPracownika;
    }

    /**
     * OSOBA_PRACOWNIK.TYP_PRACOWNIKA
     *
     * @param typPracownika
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTypPracownika(TypPrzypisaniaPracownika typPracownika) {
        this.typPracownika = typPracownika;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaPracownik other = (OsobaPracownik) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getPracownikPrzypisalId() == null ? other.getPracownikPrzypisalId() == null : this.getPracownikPrzypisalId().equals(other.getPracownikPrzypisalId()))
            && (this.getPracownikZmienilId() == null ? other.getPracownikZmienilId() == null : this.getPracownikZmienilId().equals(other.getPracownikZmienilId()))
            && (this.getDataPrzypisania() == null ? other.getDataPrzypisania() == null : this.getDataPrzypisania().equals(other.getDataPrzypisania()))
            && (this.getDataZmiany() == null ? other.getDataZmiany() == null : this.getDataZmiany().equals(other.getDataZmiany()))
            && (this.getTypPracownika() == null ? other.getTypPracownika() == null : this.getTypPracownika().equals(other.getTypPracownika()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getPracownikPrzypisalId() == null) ? 0 : getPracownikPrzypisalId().hashCode());
        result = prime * result + ((getPracownikZmienilId() == null) ? 0 : getPracownikZmienilId().hashCode());
        result = prime * result + ((getDataPrzypisania() == null) ? 0 : getDataPrzypisania().hashCode());
        result = prime * result + ((getDataZmiany() == null) ? 0 : getDataZmiany().hashCode());
        result = prime * result + ((getTypPracownika() == null) ? 0 : getTypPracownika().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", pracownikPrzypisalId=").append(pracownikPrzypisalId);
        sb.append(", pracownikZmienilId=").append(pracownikZmienilId);
        sb.append(", dataPrzypisania=").append(dataPrzypisania);
        sb.append(", dataZmiany=").append(dataZmiany);
        sb.append(", typPracownika=").append(typPracownika);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OsobaPracownik.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypPrzypisaniaPracownika;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OsobaPracownik extends GenericDPSObject {
    /**
     * OSOBA_PRACOWNIK.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * OSOBA_PRACOWNIK.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_PRZYPISAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikPrzypisalId;

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ZMIENIL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikZmienilId;

    /**
     * OSOBA_PRACOWNIK.DATA_PRZYPISANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataPrzypisania;

    /**
     * OSOBA_PRACOWNIK.DATA_ZMIANY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataZmiany;

    /**
     * OSOBA_PRACOWNIK.TYP_PRACOWNIKA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypPrzypisaniaPracownika typPracownika;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_PRACOWNIK.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * OSOBA_PRACOWNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return OSOBA_PRACOWNIK.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_PRACOWNIK.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OSOBA_PRACOWNIK.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return OSOBA_PRACOWNIK.PRACOWNIK_PRZYPISAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikPrzypisalId() {
        return pracownikPrzypisalId;
    }

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_PRZYPISAL_ID
     *
     * @param pracownikPrzypisalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikPrzypisalId(Long pracownikPrzypisalId) {
        this.pracownikPrzypisalId = pracownikPrzypisalId;
    }

    /**
     * @return OSOBA_PRACOWNIK.PRACOWNIK_ZMIENIL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikZmienilId() {
        return pracownikZmienilId;
    }

    /**
     * OSOBA_PRACOWNIK.PRACOWNIK_ZMIENIL_ID
     *
     * @param pracownikZmienilId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikZmienilId(Long pracownikZmienilId) {
        this.pracownikZmienilId = pracownikZmienilId;
    }

    /**
     * @return OSOBA_PRACOWNIK.DATA_PRZYPISANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataPrzypisania() {
        return dataPrzypisania;
    }

    /**
     * OSOBA_PRACOWNIK.DATA_PRZYPISANIA
     *
     * @param dataPrzypisania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataPrzypisania(Date dataPrzypisania) {
        this.dataPrzypisania = dataPrzypisania;
    }

    /**
     * @return OSOBA_PRACOWNIK.DATA_ZMIANY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataZmiany() {
        return dataZmiany;
    }

    /**
     * OSOBA_PRACOWNIK.DATA_ZMIANY
     *
     * @param dataZmiany
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataZmiany(Date dataZmiany) {
        this.dataZmiany = dataZmiany;
    }

    /**
     * @return OSOBA_PRACOWNIK.TYP_PRACOWNIKA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypPrzypisaniaPracownika getTypPracownika() {
        return typPracownika;
    }

    /**
     * OSOBA_PRACOWNIK.TYP_PRACOWNIKA
     *
     * @param typPracownika
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTypPracownika(TypPrzypisaniaPracownika typPracownika) {
        this.typPracownika = typPracownika;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaPracownik other = (OsobaPracownik) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getPracownikPrzypisalId() == null ? other.getPracownikPrzypisalId() == null : this.getPracownikPrzypisalId().equals(other.getPracownikPrzypisalId()))
            && (this.getPracownikZmienilId() == null ? other.getPracownikZmienilId() == null : this.getPracownikZmienilId().equals(other.getPracownikZmienilId()))
            && (this.getDataPrzypisania() == null ? other.getDataPrzypisania() == null : this.getDataPrzypisania().equals(other.getDataPrzypisania()))
            && (this.getDataZmiany() == null ? other.getDataZmiany() == null : this.getDataZmiany().equals(other.getDataZmiany()))
            && (this.getTypPracownika() == null ? other.getTypPracownika() == null : this.getTypPracownika().equals(other.getTypPracownika()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getPracownikPrzypisalId() == null) ? 0 : getPracownikPrzypisalId().hashCode());
        result = prime * result + ((getPracownikZmienilId() == null) ? 0 : getPracownikZmienilId().hashCode());
        result = prime * result + ((getDataPrzypisania() == null) ? 0 : getDataPrzypisania().hashCode());
        result = prime * result + ((getDataZmiany() == null) ? 0 : getDataZmiany().hashCode());
        result = prime * result + ((getTypPracownika() == null) ? 0 : getTypPracownika().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", pracownikPrzypisalId=").append(pracownikPrzypisalId);
        sb.append(", pracownikZmienilId=").append(pracownikZmienilId);
        sb.append(", dataPrzypisania=").append(dataPrzypisania);
        sb.append(", dataZmiany=").append(dataZmiany);
        sb.append(", typPracownika=").append(typPracownika);
        sb.append("]");
        return sb.toString();
    }
}
